@@ -14,6 +14,7 @@ from pandas import DataFrame
 
 from asammdf import MDF, Signal, SUPPORTED_VERSIONS
 from asammdf.blocks.utils import MdfException
+from asammdf.mdf import SearchMode
 
 from .utils import cycles, generate_arrays_test_file, generate_test_file
 
@@ -25,7 +26,6 @@ CHANNEL_LEN = 100000
 
 
 class TestMDF(unittest.TestCase):
-
     tempdir_demo = None
     tempdir_array = None
     tempdir_general = None
@@ -36,7 +36,6 @@ class TestMDF(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-
         url = "https://github.com/danielhrisca/asammdf/files/4078993/test.demo.zip"
         urllib.request.urlretrieve(url, "test.zip")
 
@@ -76,9 +75,7 @@ class TestMDF(unittest.TestCase):
             equal = True
 
             for inp in (input_file, BytesIO(input_file.read_bytes())):
-
                 with MDF(inp) as mdf:
-
                     for i, group in enumerate(mdf.groups):
                         if i == 0:
                             v = np.ones(cycles, dtype=np.uint64)
@@ -109,7 +106,6 @@ class TestMDF(unittest.TestCase):
                                 if not np.array_equal(vals, numexpr.evaluate(f)):
                                     equal = False
                         elif i == 4:
-
                             for j in range(1, 20):
                                 target = np.array(
                                     [
@@ -164,14 +160,11 @@ class TestMDF(unittest.TestCase):
             equal = True
 
             for inp in (input_file, BytesIO(input_file.read_bytes())):
-
                 with MDF(inp) as mdf:
                     mdf.configure(read_fragment_size=8000)
 
                     for i, group in enumerate(mdf.groups):
-
                         if i == 0:
-
                             samples = [
                                 np.ones((cycles, 2, 3), dtype=np.uint64),
                                 np.ones((cycles, 2), dtype=np.uint64),
@@ -179,7 +172,6 @@ class TestMDF(unittest.TestCase):
                             ]
 
                             for j in range(1, 20):
-
                                 types = [
                                     ("Channel_{}".format(j), "(2, 3)<u8"),
                                     ("channel_{}_axis_1".format(j), "(2, )<u8"),
@@ -197,13 +189,11 @@ class TestMDF(unittest.TestCase):
                                     1 / 0
 
                         elif i == 1:
-
                             samples = np.ones((cycles, 2, 3), dtype=np.uint64)
                             axis_0 = np.ones((cycles, 2), dtype=np.uint64)
                             axis_1 = np.ones((cycles, 3), dtype=np.uint64)
 
                             for j in range(1, 20):
-
                                 types = [("Channel_{}".format(j), "(2, 3)<u8")]
                                 types = np.dtype(types)
 
@@ -217,7 +207,6 @@ class TestMDF(unittest.TestCase):
                                     1 / 0
 
                         elif i == 2:
-
                             samples = [
                                 np.ones(cycles, dtype=np.uint8),
                                 np.ones(cycles, dtype=np.uint16),
@@ -230,7 +219,6 @@ class TestMDF(unittest.TestCase):
                             ]
 
                             for j in range(1, 20):
-
                                 types = [
                                     ("struct_{}_channel_0".format(j), np.uint8),
                                     ("struct_{}_channel_1".format(j), np.uint16),
@@ -260,7 +248,6 @@ class TestMDF(unittest.TestCase):
             self.assertTrue(equal)
 
     def test_read_demo(self):
-
         print("MDF read tests")
 
         mdf_files = [
@@ -279,9 +266,7 @@ class TestMDF(unittest.TestCase):
             print(file)
 
             for inp in (file, BytesIO(file.read_bytes())):
-
                 with MDF(inp, use_display_names=True) as input_file:
-
                     for signal in signals:
                         name = signal.stem
                         target = np.load(signal)
@@ -367,7 +352,6 @@ class TestMDF(unittest.TestCase):
                                         )
                                         1 / 0
                             elif i == 4:
-
                                 for j in range(1, 20):
                                     target = np.array(
                                         [
@@ -437,11 +421,8 @@ class TestMDF(unittest.TestCase):
         ]
 
         for file in mdf_files:
-
             for inp in (file, BytesIO(file.read_bytes())):
-
                 with MDF(inp, use_display_names=True) as input_file:
-
                     for out in SUPPORTED_VERSIONS:
                         print(file, out, type(inp))
 
@@ -452,7 +433,6 @@ class TestMDF(unittest.TestCase):
                     converted.close()
 
                     with MDF(outfile, use_display_names=True) as mdf:
-
                         for signal in signals:
                             name = signal.stem
                             target = np.load(signal)
@@ -466,13 +446,9 @@ class TestMDF(unittest.TestCase):
     def test_cut(self):
         print("MDF cut big files tests")
 
-        t = np.arange(cycles, dtype=np.float64)
-
         for input_file in Path(TestMDF.tempdir_general.name).iterdir():
             for whence in (0, 1):
                 for compression in range(3):
-                    print(input_file)
-
                     mdf = MDF(input_file)
 
                     mdf.configure(read_fragment_size=8000)
@@ -528,7 +504,6 @@ class TestMDF(unittest.TestCase):
                     concatenated.close()
 
                     with MDF(outfile) as mdf:
-
                         for i, group in enumerate(mdf.groups):
                             if i == 0:
                                 v = np.ones(cycles, dtype=np.uint64)
@@ -584,7 +559,6 @@ class TestMDF(unittest.TestCase):
                                         )
                                     self.assertTrue(cond)
                             elif i == 4:
-
                                 for j in range(1, 20):
                                     target = np.array(
                                         [
@@ -672,9 +646,7 @@ class TestMDF(unittest.TestCase):
                     mdf.configure(read_fragment_size=8000)
 
                     for i, group in enumerate(mdf.groups):
-
                         if i == 0:
-
                             samples = [
                                 np.ones((cycles, 2, 3), dtype=np.uint64),
                                 np.ones((cycles, 2), dtype=np.uint64),
@@ -682,7 +654,6 @@ class TestMDF(unittest.TestCase):
                             ]
 
                             for j in range(1, 20):
-
                                 types = [
                                     ("Channel_{}".format(j), "(2, 3)<u8"),
                                     ("channel_{}_axis_1".format(j), "(2, )<u8"),
@@ -709,13 +680,11 @@ class TestMDF(unittest.TestCase):
                                     1 / 0
 
                         elif i == 1:
-
                             samples = np.ones((cycles, 2, 3), dtype=np.uint64)
                             axis_0 = np.ones((cycles, 2), dtype=np.uint64)
                             axis_1 = np.ones((cycles, 3), dtype=np.uint64)
 
                             for j in range(1, 20):
-
                                 types = [("Channel_{}".format(j), "(2, 3)<u8")]
                                 types = np.dtype(types)
 
@@ -729,7 +698,6 @@ class TestMDF(unittest.TestCase):
                                     1 / 0
 
                         elif i == 2:
-
                             samples = [
                                 np.ones(cycles, dtype=np.uint8),
                                 np.ones(cycles, dtype=np.uint16),
@@ -742,7 +710,6 @@ class TestMDF(unittest.TestCase):
                             ]
 
                             for j in range(1, 20):
-
                                 types = [
                                     ("struct_{}_channel_0".format(j), np.uint8),
                                     ("struct_{}_channel_1".format(j), np.uint16),
@@ -785,9 +752,7 @@ class TestMDF(unittest.TestCase):
             print(file)
 
             for inp in (file, BytesIO(file.read_bytes())):
-
                 with MDF(inp, use_display_names=True) as input_file:
-
                     for whence in (0, 1):
                         print(file, whence)
 
@@ -825,7 +790,6 @@ class TestMDF(unittest.TestCase):
                         concatenated.close()
 
                         with MDF(outfile, use_display_names=True) as mdf2:
-
                             for signal in signals:
                                 target = np.load(signal)
                                 sig = mdf2.get(
@@ -844,7 +808,6 @@ class TestMDF(unittest.TestCase):
                     inp.close()
 
     def test_filter(self):
-
         print("MDF read tests")
 
         mdf_files = [
@@ -863,9 +826,7 @@ class TestMDF(unittest.TestCase):
             print(file)
 
             for inp in (file, BytesIO(file.read_bytes())):
-
                 with MDF(inp, use_display_names=True) as input_file:
-
                     names = [
                         ch.name for gp in input_file.groups for ch in gp.channels[1:]
                     ]
@@ -909,9 +870,7 @@ class TestMDF(unittest.TestCase):
             print(file)
 
             for inp in (file, BytesIO(file.read_bytes())):
-
                 with MDF(inp, use_display_names=True) as input_file:
-
                     names = [
                         ch.name for gp in input_file.groups for ch in gp.channels[1:]
                     ]
@@ -1037,6 +996,76 @@ class TestMDF(unittest.TestCase):
         self.assertTrue(target.equals(mdf.to_dataframe()))
         mdf.close()
 
+    def test_search(self):
+        sigs = [
+            Signal(
+                samples=np.ones(1),
+                timestamps=np.arange(1),
+                name=ch_name,
+            )
+            for ch_name in ["foo", "Bar", "baz"]
+        ]
+        mdf = MDF()
+        mdf.append(sigs)
+
+        # plain text matching
+        self.assertEqual(["foo"], mdf.search(pattern="foo"), msg="name match full")
+        self.assertEqual(
+            ["foo"], mdf.search(pattern="oo", mode="plain"), msg="name match part"
+        )
+        self.assertEqual(
+            [],
+            mdf.search(pattern="FOO", mode=SearchMode.plain, case_insensitive=False),
+            msg="name match case-sensitive (no match)",
+        )
+        self.assertEqual(
+            ["foo"],
+            mdf.search(pattern="FOO", mode=SearchMode.plain, case_insensitive=True),
+            msg="name match case-insensitive (match)",
+        )
+
+        # regex matching
+        self.assertEqual(
+            ["Bar"], mdf.search(pattern="^Bar$", mode="regex"), msg="regex match full"
+        )
+        self.assertEqual(
+            ["baz"],
+            mdf.search(pattern="z$", mode=SearchMode.regex),
+            msg="regex match part",
+        )
+        self.assertEqual(
+            ["baz"],
+            mdf.search(pattern="b.*", mode=SearchMode.regex, case_insensitive=False),
+            msg="regex match case-sensitive",
+        )
+        self.assertEqual(
+            ["Bar", "baz"],
+            mdf.search(pattern="b.*", mode=SearchMode.regex, case_insensitive=True),
+            msg="regex match case-insensitive",
+        )
+
+        # wildcard matching
+        self.assertEqual(
+            ["Bar"],
+            mdf.search(pattern="Bar", mode="wildcard"),
+            msg="wildcard match full",
+        )
+        self.assertEqual(
+            ["foo"],
+            mdf.search(pattern="*oo", mode=SearchMode.wildcard),
+            msg="wildcard match part",
+        )
+        self.assertEqual(
+            ["baz"],
+            mdf.search(pattern="b*", mode=SearchMode.wildcard, case_insensitive=False),
+            msg="wildcard match case-sensitive",
+        )
+        self.assertEqual(
+            ["Bar", "baz"],
+            mdf.search(pattern="b*", mode=SearchMode.wildcard, case_insensitive=True),
+            msg="wildcard match case-insensitive",
+        )
+
 
 if __name__ == "__main__":
     unittest.main()
