@@ -1,6 +1,4 @@
 #!/usr/bin/env python
-from __future__ import print_function
-
 import unittest
 
 import numpy as np
@@ -249,7 +247,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(np.arange(5, dtype="<f8"), res.timestamps))
 
         res = s.cut(start=0.5)
-        self.assertTrue(np.array_equal([0.5, 1, 2, 3, 4], res.samples))
+        self.assertTrue(np.allclose([0.5, 1, 2, 3, 4], res.samples))
         self.assertTrue(
             np.array_equal(np.array([0.5, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
         )
@@ -295,7 +293,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(np.array([0], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=0.5)
-        self.assertTrue(np.array_equal([0, 0.5], res.samples))
+        self.assertTrue(np.allclose([0, 0.5], res.samples))
         self.assertTrue(np.array_equal(np.array([0, 0.5], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=0.5, include_ends=False)
@@ -345,7 +343,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(np.array([0], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=-2, stop=0.5)
-        self.assertTrue(np.array_equal([0, 0.5], res.samples))
+        self.assertTrue(np.allclose([0, 0.5], res.samples))
         self.assertTrue(np.array_equal(np.array([0, 0.5], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=-2, stop=0.5, include_ends=False)
@@ -353,7 +351,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(np.array([0], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=-2, stop=1.1)
-        self.assertTrue(np.array_equal([0, 1, 1.1], res.samples))
+        self.assertTrue(np.allclose([0, 1, 1.1], res.samples))
         self.assertTrue(
             np.array_equal(np.array([0, 1, 1.1], dtype="<f8"), res.timestamps)
         )
@@ -371,9 +369,9 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(np.array([0, 1], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=0.1, stop=3.5)
-        self.assertTrue(np.array_equal([0.1, 1, 2, 3, 3.5], res.samples))
+        self.assertTrue(np.allclose([0.1, 1, 2, 3, 3.5], res.samples))
         self.assertTrue(
-            np.array_equal(np.array([0.1, 1, 2, 3, 3.5], dtype="<f8"), res.timestamps)
+            np.allclose(np.array([0.1, 1, 2, 3, 3.5], dtype="<f8"), res.timestamps)
         )
 
         res = s.cut(start=0.1, stop=3.5, include_ends=False)
@@ -383,18 +381,16 @@ class TestSignal(unittest.TestCase):
         )
 
         res = s.cut(start=1.1, stop=1.9)
-        self.assertTrue(np.array_equal([1.1, 1.9], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([1.1, 1.9], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.allclose([1.1, 1.9], res.samples))
+        self.assertTrue(np.allclose(np.array([1.1, 1.9], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=1.1, stop=1.9, include_ends=False)
         self.assertTrue(np.array_equal([], res.samples))
         self.assertTrue(np.array_equal(np.array([], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=3.5, stop=4.5)
-        self.assertTrue(np.array_equal([3.5, 4], res.samples))
-        self.assertTrue(np.array_equal(np.array([3.5, 4], dtype="<f8"), res.timestamps))
+        self.assertTrue(np.allclose([3.5, 4], res.samples))
+        self.assertTrue(np.allclose(np.array([3.5, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=3.5, stop=4.5, include_ends=False)
         self.assertTrue(np.array_equal([4], res.samples))
@@ -522,7 +518,7 @@ class TestSignal(unittest.TestCase):
 
         target = np.arange(1, 5, dtype="<f4") ** 3
 
-        res = s ** 3
+        res = s**3
         self.assertTrue(np.array_equal(res.samples, target))
 
 
